@@ -31,7 +31,7 @@
     <message>
         <location filename="mainwindow.ui" line="40"/>
         <source>Minimum CPU speed:</source>
-        <translation>Min. CPU Frequenz:</translation>
+        <translation>Min. CPU-Frequenz:</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="47"/>
@@ -46,7 +46,7 @@
     <message>
         <location filename="mainwindow.ui" line="60"/>
         <source>Maximum CPU speed:</source>
-        <translation>Max. CPU Frequenz:</translation>
+        <translation>Max. CPU-Frequenz:</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="80"/>
@@ -72,7 +72,7 @@
     <message>
         <location filename="mainwindow.ui" line="336"/>
         <source>Set maximum CPU frequency:</source>
-        <translation>Maximale CPU Frequenz einstellen:</translation>
+        <translation>Maximale CPU-Frequenz einstellen:</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="364"/>
