@@ -28,7 +28,7 @@
 #endif
 
 #define APPNAME "QCPUFreq"
-#define APPVERSION "0.4.1"
+#define APPVERSION "0.4.2"
 
 
 MainWindow::MainWindow(QWidget *parent) :
@@ -54,6 +54,10 @@ MainWindow::MainWindow(QWidget *parent) :
     settings = new Settings;
     settings->hide();
 
+    //load preset dialog
+    loadPresetDialog = new LoadPreset;
+    loadPresetDialog->hide();
+
     init();
 
     //applies the settings from the settings dialog
@@ -82,13 +86,16 @@ MainWindow::MainWindow(QWidget *parent) :
     connect(ui->sr_box, SIGNAL(clicked()), this, SLOT(setSmartReflex()));
     connect(&refreshTimer, SIGNAL(timeout()), this, SLOT(refresh()));
     connect(ui->actionSave, SIGNAL(triggered()), this, SLOT(save()));
+    connect(ui->actionLoad, SIGNAL(triggered()), loadPresetDialog, SLOT(show()));
     connect(ui->actionSettings, SIGNAL(triggered()), this, SLOT(showSettings()));
     connect(settings, SIGNAL(settingsChanged()), this, SLOT(applySettings()));
+    connect(loadPresetDialog, SIGNAL(load(QString)), this, SLOT(loadPreset(QString)));
 
 }
 
 MainWindow::~MainWindow()
 {
+    delete loadPresetDialog;
     delete settings;
     delete ui;
 }
@@ -153,6 +160,13 @@ void MainWindow::applySettings()
     setAutoRotation();
     setAdvancedTemperature();
 
+    //if overclocking is/was enabled we can also enable the "Load preset" option
+    if (settings->useOverclocking() && settings->usePowerKernel() && settings->isKernelConfigInstalled()) {
+        ui->actionLoad->setEnabled(true);
+    } else {
+        ui->actionLoad->setEnabled(false);
+    }
+
     //refresh the GUI after applying the settings
     refresh();
 }
@@ -356,19 +370,39 @@ void MainWindow::init()
     } else {
         this->minFreq = min.toInt();
     }
+    file.close();
 
-    //enable save option on power kernels
-    if (settings->usePowerKernel()) {
-        //only enable save if /usr/sbin/kernel-config is present
-        file.close();
-        file.setFileName("/usr/sbin/kernel-config");
-        if (file.exists()) {
-            ui->actionSave->setEnabled(true);
+    //enable save and load option on power kernels
+    if (settings->usePowerKernel() && settings->isKernelConfigInstalled()) {
+        ui->actionSave->setEnabled(true);
+        //loading presets may cause overclocking - only enable it if overclokcing is enabled
+        if (settings->useOverclocking()) {
+            ui->actionLoad->setEnabled(true);
         }
     }
 }
 
 
+/**
+  * Loads a voltage preset by calling kernel-config.
+  *
+  * Available presets are:
+  *  - default
+  *  - ideal
+  *  - lv
+  *  - ulv
+  *  - xlv
+  *  - custom -> any preset named "custom"
+  */
+void MainWindow::loadPreset(QString presetName)
+{
+    #if defined(Q_WS_MAEMO_5)
+        callHelper("loadpreset", presetName);
+        QMaemo5InformationBox::information(this, tr( "The preset was loaded." ), QMaemo5InformationBox::DefaultTimeout);
+    #endif
+}
+
+
 /**
   * Reads any file in /sys/
   *
@@ -495,6 +529,7 @@ void MainWindow::setAutoRotation()
 {
 #if defined(Q_WS_MAEMO_5)
     setAttribute(Qt::WA_Maemo5AutoOrientation, settings->useAutoRotate());
+    loadPresetDialog->setAttribute(Qt::WA_Maemo5AutoOrientation, settings->useAutoRotate());
     settings->setAttribute(Qt::WA_Maemo5AutoOrientation, settings->useAutoRotate());
 #endif
 }
