@@ -33,6 +33,7 @@ class Settings : public QDialog
 public:
     explicit Settings(QWidget *parent = 0);
     ~Settings();
+    bool isKernelConfigInstalled();
     bool platformMaemo();
     bool useAdvancedTemperature();
     bool useAutoRotate();
@@ -52,6 +53,7 @@ private:
     bool autoRotate;
     bool overclocking;
     bool powerKernel;
+    bool kernelConfigInstalled;
     QSettings settings;
     Ui::Settings *ui;
 };
